package Bencher::Scenario::IntValidation;

our $DATE = '2017-01-25'; # DATE
our $VERSION = '0.002'; # VERSION

use 5.010001;
use strict;
use warnings;

our $scenario = {
    summary => 'Which method of checking for integer is fastest in Perl?',
    participants => [
        {
            name => 'regex',
            code_template  => '<data> =~ /\A-?[0-9]+\z/',
        },
        {
            name=>'SUN::isint',
            fcall_template => 'Scalar::Util::Numeric::isint(<data>)',
        },
        {
            name=>'SUN::PP::isint',
            fcall_template => 'Scalar::Util::Numeric::PP::isint(<data>)',
        },
    ],

    datasets => [
        {
            args => {
                'data@' => [0, 1, -1, "foo"],
            },
        },
    ],
};

1;
# ABSTRACT: Which method of checking for integer is fastest in Perl?

__END__

=pod

=encoding UTF-8

=head1 NAME

Bencher::Scenario::IntValidation - Which method of checking for integer is fastest in Perl?

=head1 VERSION

This document describes version 0.002 of Bencher::Scenario::IntValidation (from Perl distribution Bencher-Scenario-IntValidation), released on 2017-01-25.

=head1 SYNOPSIS

To run benchmark with default option:

 % bencher -m IntValidation

To run module startup overhead benchmark:

 % bencher --module-startup -m IntValidation

For more options (dump scenario, list/include/exclude/add participants, list/include/exclude/add datasets, etc), see L<bencher> or run C<bencher --help>.

=head1 DESCRIPTION

Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.

=head1 BENCHMARKED MODULES

Version numbers shown below are the versions used when running the sample benchmark.

L<Scalar::Util::Numeric> 0.40

L<Scalar::Util::Numeric::PP> 0.04

=head1 BENCHMARK PARTICIPANTS

=over

=item * regex (perl_code)

Code template:

 <data> =~ /\A-?[0-9]+\z/



=item * SUN::isint (perl_code)

Function call template:

 Scalar::Util::Numeric::isint(<data>)



=item * SUN::PP::isint (perl_code)

Function call template:

 Scalar::Util::Numeric::PP::isint(<data>)



=back

=head1 BENCHMARK DATASETS

=over

=item * [0,1,-1,"foo"]

=back

=head1 SAMPLE BENCHMARK RESULTS

Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.

Benchmark with default options (C<< bencher -m IntValidation >>):

 #table1#
 +----------------+----------+-----------+-----------+------------+---------+---------+
 | participant    | arg_data | rate (/s) | time (ns) | vs_slowest |  errors | samples |
 +----------------+----------+-----------+-----------+------------+---------+---------+
 | SUN::PP::isint | -1       |   1800000 |     570   |      1     | 6.2e-10 |      20 |
 | SUN::PP::isint | 1        |   1874000 |     533.6 |      1.064 | 4.5e-11 |      20 |
 | SUN::PP::isint | 0        |   2000000 |     501   |      1.13  | 1.4e-10 |      24 |
 | SUN::PP::isint | foo      |   2420000 |     413   |      1.38  | 1.5e-10 |      29 |
 | SUN::isint     | -1       |   5100000 |     196   |      2.89  |   1e-10 |      20 |
 | regex          | -1       |   5602000 |     178.5 |      3.181 | 1.1e-11 |      20 |
 | regex          | 0        |   5950000 |     168   |      3.38  | 1.1e-10 |      24 |
 | regex          | 1        |   5970000 |     168   |      3.39  | 1.1e-10 |      20 |
 | regex          | foo      |   6690000 |     149   |      3.8   | 3.4e-11 |      20 |
 | SUN::isint     | foo      |  12000000 |      86   |      6.6   | 1.9e-10 |      20 |
 | SUN::isint     | 0        |  12000000 |      83   |      6.9   | 1.5e-10 |      25 |
 | SUN::isint     | 1        |  13000000 |      76   |      7.4   | 3.1e-10 |      20 |
 +----------------+----------+-----------+-----------+------------+---------+---------+


Benchmark module startup overhead (C<< bencher -m IntValidation --module-startup >>):

 #table2#
 +---------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
 | participant               | proc_private_dirty_size (MB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
 +---------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
 | Scalar::Util::Numeric     | 1.2                          | 4.6                | 18             |      11   |                    5.3 |        1   | 5.9e-05 |      20 |
 | Scalar::Util::Numeric::PP | 0.95                         | 4.4                | 16             |       9   |                    3.3 |        1.2 |   4e-05 |      20 |
 | perl -e1 (baseline)       | 0.82                         | 4.1                | 16             |       5.7 |                    0   |        2   | 1.7e-05 |      20 |
 +---------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+


To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Bencher-Scenario-IntValidation>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Bencher-Scenario-IntValidation>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Bencher-Scenario-IntValidation>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2017 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
